@@ -1,10 +1,10 @@
 #-----------------------------------------------------------------------------
 #
-#	$Id : Meta.pm 1.006 2005-03-31 JMG$
+#	$Id : Meta.pm 2.006 2005-05-10 JMG$
 #
 #	Initial developer: Jean-Marie Gouarne
-#	Copyright 2004 by Genicorp, S.A. (www.genicorp.com)
-#	Licensing conditions:
+#	Copyright 2005 by Genicorp, S.A. (www.genicorp.com)
+#	License:
 #		- Licence Publique Generale Genicorp v1.0
 #		- GNU Lesser General Public License v2.1
 #	Contact: oodoc@genicorp.com
@@ -13,9 +13,9 @@
 
 package	OpenOffice::OODoc::Meta;
 use	5.006_001;
-our	$VERSION	= 1.006;
+our	$VERSION	= 2.006;
 
-use	OpenOffice::OODoc::XPath	1.115;
+use	OpenOffice::OODoc::XPath	2.115;
 require Exporter;
 our	@ISA		= qw ( OpenOffice::OODoc::XPath Exporter );
 our	@EXPORT		= qw ( ooLocaltime ooTimelocal );
@@ -63,8 +63,16 @@ sub	new
 		);
 
 	my $object = $class->SUPER::new(%options);
-	if ($object)	{ return bless $object, $class; }
-	else		{ return undef; }
+	if ($object)
+		{
+		bless $object, $class;
+		$object->{'body'}	= $object->getBody();
+		return $object;
+		}
+	else
+		{
+		return undef;
+		}
 	}
 
 #-----------------------------------------------------------------------------
@@ -81,7 +89,7 @@ sub	accessor
 		my $name	= $path;
 		$name	=~ s/\/*//g;
 		$element = $self->appendElement
-				($self->getBody, $name, text => $value);
+				($self->{'body'}, $name, text => $value);
 		return $value;
 		}
 
@@ -200,12 +208,37 @@ sub	editing_duration
 # result is an array of strings or a single string (with ',' as keyword
 # separator) ; optional newly added keywords are included in the result set
 
-sub	keywords
+sub	_od_keywords		# Open Document version
+	{
+	my $self	= shift;
+	my @new_kws	= @_;
+
+	my @list	= $self->getTextList('//meta:keyword');
+	my $body	= $self->{'body'};
+	NEW_KWS: foreach my $new_kw (@new_kws)
+		{
+		foreach my $old_kw (@list)
+			{
+			next NEW_KWS if ($old_kw eq $new_kw);
+			}
+		
+		$self->appendElement
+				(
+				$body,
+				'meta:keyword',
+				text	=> $new_kw
+				);
+		push @list, $new_kw;
+		}
+	return wantarray ? @list : join ", ", @list;
+	}
+
+sub	_oo_keywords		# OpenOffice.org version
 	{
 	my $self	= shift;
 	my @new_words	= @_;
 
-	$self->addKeyword($_)	for @new_words;
+	$self->_oo_addKeyword($_)	for @new_words;
 	
 	my $base	= $self->getElement('//meta:keywords', 0);
 	return undef	unless $base;
@@ -219,10 +252,37 @@ sub	keywords
 	return wantarray ? @list : join ", ", @list;
 	}
 
+sub	keywords
+	{
+	my $self	= shift;
+	return ($self->{'opendocument'}) ?
+		$self->_od_keywords(@_)	: $self->_oo_keywords(@_);
+	}
+	
 #-----------------------------------------------------------------------------
 # append a new keyword (if unknown) in the keywords list
 
-sub	addKeyword
+sub	_od_addKeyword		# Open Document version
+	{
+	my $self	= shift;
+	my $new_kw	= shift or return undef;
+
+	my @list	= $self->getTextList('//meta:keyword');
+	foreach my $old_kw (@list)
+		{
+		return undef if ($new_kw eq $old_kw);
+		}
+
+	$self->appendElement
+			(
+			$self->{'body'},
+			'meta:keyword',
+			text => $new_kw
+			);
+	return $new_kw;
+	}
+
+sub	_oo_addKeyword		# OpenOffice.org version
 	{
 	my $self	= shift;
 	my $new_word	= shift;
@@ -247,36 +307,90 @@ sub	addKeyword
 	return $new_word;
 	}
 
+sub	addKeyword
+	{
+	my $self	= shift;
+	return $self->{'opendocument'} ?
+		$self->_od_addKeyword(@_) : $self->_oo_addKeyword(@_);
+	}
+
 #-----------------------------------------------------------------------------
 # remove a given keyword (if known) from the keyword list
 
-sub	removeKeyword
+sub	_od_removeKeyword	# Open Document version
+	{
+	my $self	= shift;
+	my $kw		= shift;
+
+	my @list	= $self->getElementList('//meta:keyword');
+	my $count	= 0;
+	foreach my $element (@list)
+		{
+		my $old_kw = $self->getText($element);
+		if ($old_kw eq $kw)
+			{
+			$self->removeElement($element);
+			$count++;
+			}
+		}
+	return $count;
+	}
+
+sub	_oo_removeKeyword	# OpenOffice.org version
 	{
 	my $self	= shift;
 	my $word	= shift;
 
 	my $kw_base	= $self->getElement('//meta:keywords', 0);
 	return undef	unless $kw_base;
-	
+	my $count	= 0;	
 	foreach my $element
 		($self->selectChildElementsByName($kw_base, 'meta:keyword'))
 		{
 		my $old_word	= $self->getText($element);
-		$kw_base->removeChild($element)	if ($old_word =~ /$word/);
+		if ($old_word eq $word)
+			{
+			$kw_base->removeChild($element);
+			$count++;
+			}
 		}
+	return $count;
 	}
-	
+
+sub	removeKeyword
+	{
+	my $self	= shift;
+	return $self->{'opendocument'} ?
+		$self->_od_removeKeyword(@_) : $self->_oo_removeKeyword(@_);
+	}
+
 #-----------------------------------------------------------------------------
 # remove the keyword list
 
+sub	_od_removeKeywords	# Open Document version
+	{
+	my $self	= shift;
+
+	my @list	= $self->getElementList('//meta:keyword');
+	my $count	= 0;
+	foreach my $element (@list)
+		{
+		$count++;
+		$self->removeElement($element);
+		}
+	return $count;
+	}
+
 sub	removeKeywords
 	{
 	my $self	= shift;
-	return $self->removeElement('//meta:keywords', 0);
+	return ($self->{'opendocument'}) ?
+		$self->_od_removeKeywords(@_)	:
+		$self->removeElement('//meta:keywords', 0);
 	}
 
 #-----------------------------------------------------------------------------
-# get/set the list of the 4 user defined fields of the meta-data
+# get/set the list of the user defined fields of the meta-data
 # without argument, returns a hash where keys are the field names
 # and values are the field values
 # to set/update the user-defined fields, arguments should be passed
